TenorSearchFieldStyle class

Constructors

TenorSearchFieldStyle({Color fillColor = Colors.white, TextStyle hintStyle = const TextStyle(color: Color(0xFF8A8A86), fontSize: 16, fontWeight: FontWeight.normal), TextStyle textStyle = const TextStyle(color: Color(0xFF000000), fontSize: 16, fontWeight: FontWeight.normal)})
const

Properties

fillColor Color
final
hashCode int
The hash code for this object.
no setterinherited
hintStyle TextStyle
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited