tenor_flutter library
Classes
- Tenor
- TenorAttributionStyle
- TenorCategory
- Based on category response object from the Tenor API.
- TenorDragHandleStyle
- TenorHttpClient
- A class for handling requests to HTTP.
- TenorMediaFormat
- A class contianing all the media formats supported by Tenor API.
- TenorMediaFormats
- Based on content formats from the Tenor API.
- TenorMediaObject
- Based on media response object from the Tenor API.
- TenorResponse
- Based on category response object from the Tenor API.
- TenorResult
- Based on category response object from the Tenor API.
- TenorSearchFieldStyle
- TenorSelectedCategoryStyle
- TenorStyle
- TenorTab
- TenorTabBarStyle
- TenorTabView
- TenorTabViewStyle
- TenorViewEmojis
- TenorViewGifs
- TenorViewStickers
Enums
- TenorAspectRatioRange
- Filter the Response Objects to only include GIFs with aspect ratios that fit within the selected range.
- TenorAttributionType
- It is your responsibility to display attribution via atleast one of the following methods.
- TenorCategoryType
- Determines the type of categories returned.
- TenorContentFilter
- Filters are designed to map to the Motion Picture Association (MPA).
- TenorEndpoint
- Implemented endpoints from the Tenor API
Constants
- tenorApiUrl → const String
- tenorDefaultAnimationStyle → const AnimationStyle