TenorResult class
Based on category response object from the Tenor API.
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
TenorResult({required String contentDescription, required double created, required List<
String> flags, required bool hasAudio, required bool hasCaption, required String id, required String itemUrl, required List<String> tags, required String title, required String url, String? bgColor, TenorMediaFormats media = const TenorMediaFormats(), String? source}) -
TenorResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
- bgColor → String?
-
The most common background pixel color of the content
final
- contentDescription → String
-
A textual description of the content.
final
- created → double
-
A Unix timestamp that represents when this post was created.
final
-
flags
→ List<
String> -
Comma-separated list to signify whether the content is a sticker or static image, has audio, or is any combination of these.
final
- hasAudio → bool
-
eturns true if this post contains audio.
final
- hasCaption → bool
-
Returns true if this post contains captions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Tenor result identifier
final
- itemUrl → String
-
The full URL to view the post on tenor.com.
final
- media → TenorMediaFormats
-
A dictionary with a content format as the key and a Media Object as the value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String?
-
Analytical value to track the source of where this GIF came from. For instance which Tab in a UI.
final
-
An array of tags for the post
final
- title → String
-
The title of the post
final
- url → String
-
A short URL to view the post on tenor.com.
final
Methods
-
copyWith(
{double? created, bool? hasAudio, String? id, TenorMediaFormats? media, List< String> ? tags, String? title, String? contentDescription, String? itemUrl, bool? hasCaption, List<String> ? flags, String? bgColor, String? url, String? source}) → TenorResult -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited